@@ -460,7 +460,7 @@ class CloudPods:
             return None
 
     @enter_and_leave_function
-    def get_server_ip(self, server_id):
+    def get_server_ip(self, server_id,network_id=""):
         server = self.get_server_detail(server_id)
         if not server:
             log.warning(f"failed get server info by server name {server_id}, server info is {server}.")
@@ -477,7 +477,16 @@ class CloudPods:
         if "ip_addr" not in server["server"]["nics"][0].keys():
             log.warning(f"ip_addr do not in server['server']['nics'][0], server['server']['nics'][0] is {server['server']['nics'][0]}")
             return None
-        return server["server"]["nics"][0]["ip_addr"]
+        if not network_id:
+            server_ip=["server"]["nics"][0]["ip_addr"]
+            return server_ip
+        else:
+            for nic in server["server"]["nics"]:
+                if nic["network_id"]==network_id:
+                    server_ip=nic["ip_addr"]
+                    return server_ip
+            else:
+                return None
 
     @enter_and_leave_function
     def wait_for_server_is_on(self, server_id,timeout=1800):
